@@ -342,7 +342,7 @@ class Run():
                 print(clogger.name, clogger.memoize)
 
         if save_model == True:
-            class_type = type(target)
+            class_type = str(type(target))
             if target == None:
                 print('no model specified, skipping')
                 pass
@@ -350,6 +350,7 @@ class Run():
                 if 'keras' in class_type:
                     print('Keras Model detected, saving to ./saved_model.pb')
                     target.save('saved_model.pb')
+                    pass
                 if 'tensorflow' in class_type and 'keras' not in class_type:
                     if target._closed:
                         print(
@@ -360,12 +361,14 @@ class Run():
                         import tensorflow as tf
                         saver = tf.train.Saver()
                         saver.save(target, 'saved_model.pb')
-                else:
-                    if target.state_dict:
+                        pass
+                elif 'tensorflow' not in class_type and 'keras' not in class_type:
+                    try:
                         print('Torch Model detected, saving to ./saved_model.pth')
                         import torch
                         torch.save(target.state_dict(), 'saved_model.pth')
-                    else:
+                        pass
+                    except:
                         print('model cannot be saved, please check format')
 
         if self.remote_path:
@@ -390,8 +393,8 @@ class Run():
                 else:
                     print("conclude remote call succeed. resp:", r)
                     break
-        if upload_model:
-            self.__upload_model()
+        # if upload_model:
+        #     self.__upload_model()
         self.started = False
         self.run_id = "concluded"
 
